@@ -377,6 +377,8 @@ ORDER BY total_bytes DESC;
 @click.option('-f', '--file')
 @pass_config
 def excel(config, sql, file):
+    if sql.startswith("'") and sql.endswith("'"):
+        sql = sql[1:-1]
     import xlsxwriter
     conn = config.get_odoo_conn()
     columns, rows = _execute_sql(conn, sql, fetchall=True, return_columns=True)
@@ -386,6 +388,7 @@ def excel(config, sql, file):
     else:
         filepath = Path(os.getcwd()) / f"{conn.dbname}_{arrow.get().strftime('%Y-%m-%d%H-%M-%S')}.xlsx"
 
+
     # Workbook() takes one, non-optional, argument
     # which is the filename that we want to create.
     workbook = xlsxwriter.Workbook(str(filepath))
@@ -404,7 +407,11 @@ def excel(config, sql, file):
             click.secho(f"Done {irow} rows...")
 
     workbook.close()
+
     click.secho(f"File created: {filepath}")
+    if config.owner_uid:
+        cmd = f'chown {config.owner_uid}:{config.owner_uid} "{filepath}"'
+        os.system(cmd)
 
 
 Commands.register(reset_db, 'reset-db')
